<?php

namespace Litecms\Casestudy\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Casestudy\Http\Requests\CasestudyRequest;
use Litecms\Casestudy\Interfaces\CasestudyRepositoryInterface;
use Litecms\Casestudy\Models\Casestudy;

/**
 * Resource controller class for casestudy.
 */
class CasestudyResourceController extends BaseController
{

    /**
     * Initialize casestudy resource controller.
     *
     * @param type CasestudyRepositoryInterface $casestudy
     *
     * @return null
     */
    public function __construct(CasestudyRepositoryInterface $casestudy)
    {
        parent::__construct();
        $this->repository = $casestudy;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Casestudy\Repositories\Criteria\CasestudyResourceCriteria::class);
    }

    /**
     * Display a list of casestudy.
     *
     * @return Response
     */
    public function index(CasestudyRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Casestudy\Repositories\Presenter\CasestudyPresenter::class)
                ->$function();
        }

        $casestudies = $this->repository->paginate();

        return $this->response->title(trans('casestudy::casestudy.names'))
            ->view('casestudy::casestudy.index', true)
            ->data(compact('casestudies'))
            ->output();
    }

    /**
     * Display casestudy.
     *
     * @param Request $request
     * @param Model   $casestudy
     *
     * @return Response
     */
    public function show(CasestudyRequest $request, Casestudy $casestudy)
    {

        if ($casestudy->exists) {
            $view = 'casestudy::casestudy.show';
        } else {
            $view = 'casestudy::casestudy.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('casestudy::casestudy.name'))
            ->data(compact('casestudy'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new casestudy.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CasestudyRequest $request)
    {

        $casestudy = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('casestudy::casestudy.name')) 
            ->view('casestudy::casestudy.create', true) 
            ->data(compact('casestudy'))
            ->output();
    }

    /**
     * Create new casestudy.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CasestudyRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $casestudy                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('casestudy::casestudy.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('casestudy/casestudy/' . $casestudy->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/casestudy/casestudy'))
                ->redirect();
        }

    }

    /**
     * Show casestudy for editing.
     *
     * @param Request $request
     * @param Model   $casestudy
     *
     * @return Response
     */
    public function edit(CasestudyRequest $request, Casestudy $casestudy)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('casestudy::casestudy.name'))
            ->view('casestudy::casestudy.edit', true)
            ->data(compact('casestudy'))
            ->output();
    }

    /**
     * Update the casestudy.
     *
     * @param Request $request
     * @param Model   $casestudy
     *
     * @return Response
     */
    public function update(CasestudyRequest $request, Casestudy $casestudy)
    {
        try {
            $attributes = $request->all();

            $casestudy->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('casestudy::casestudy.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('casestudy/casestudy/' . $casestudy->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('casestudy/casestudy/' . $casestudy->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the casestudy.
     *
     * @param Model   $casestudy
     *
     * @return Response
     */
    public function destroy(CasestudyRequest $request, Casestudy $casestudy)
    {
        try {

            $casestudy->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('casestudy::casestudy.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('casestudy/casestudy/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('casestudy/casestudy/' . $casestudy->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple casestudy.
     *
     * @param Model   $casestudy
     *
     * @return Response
     */
    public function delete(CasestudyRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('casestudy::casestudy.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('casestudy/casestudy'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/casestudy/casestudy'))
                ->redirect();
        }

    }

    /**
     * Restore deleted casestudies.
     *
     * @param Model   $casestudy
     *
     * @return Response
     */
    public function restore(CasestudyRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('casestudy::casestudy.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/casestudy/casestudy'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/casestudy/casestudy/'))
                ->redirect();
        }

    }

}
